## What is TOPSIS

**T**echnique for **O**rder **P**reference by **S**imilarity to **I**deal
**S**olution (TOPSIS) originated in the 1980s as a multi-criteria decision
making method. TOPSIS chooses the alternative of shortest Euclidean distance
from the ideal solution, and farthest distance from the negative-ideal
solution. More details at [wikipedia](https://en.wikipedia.org/wiki/TOPSIS)


## Installation
```pip install Topsis-Nanaki-101903195```

## How to use it ?
Open terminal and move into directory where all your files are placed and the type :
    python topsis.py "input.csv" "1,1,1,2" "+,+,+,-" "result.csv"

## License 
© 2022 
This repository is licensed under the MIT license.See License for details.